@@ -675,6 +675,13 @@ polydi= {cat("Call: ")
     }
     },
 
+validity = { cat("Call: ")
+    print(x$Call)
+	cat("\nPredicted Asymptotic Scale Validity:\n")
+	  print(x$asymptotic,digits) 
+	 cat("\n For predicted scale validities, average item validities, or scale reliabilities, print the separate objects")
+     }, 
+
 overlap =  {
     cat("Call: ")
     print(x$Call)
